==> haskell-rank2classes-1.4-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rank2classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rank2classes
version:              1.4
visibility:           public
id:                   rank2classes-1.4-9KaPbVHV9WwDmas9Giv5PK
key:                  rank2classes-1.4-9KaPbVHV9WwDmas9Giv5PK
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  b2cc7e2e45c1209c8c11e0ef486f6689
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-8.8.3/site-local/rank2classes-1.4
library-dirs:         /usr/lib/ghc-8.8.3/site-local/rank2classes-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/rank2classes-1.4
hs-libraries:         HSrank2classes-1.4-9KaPbVHV9WwDmas9Giv5PK
depends:
    base-4.13.0.0 distributive-0.6.1-2oWTigw2Te26PrNZL2y3v5
    template-haskell-2.15.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rank2classes-1.4.4-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rank2classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rank2classes
version:              1.4.4
visibility:           public
id:                   rank2classes-1.4.4-2FQFu50UwTCZnaeg8QB8J
key:                  rank2classes-1.4.4-2FQFu50UwTCZnaeg8QB8J
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  713961999a44b9799d994b9c3a43b297
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-9.0.2/site-local/rank2classes-1.4.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/rank2classes-1.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/rank2classes-1.4.4
hs-libraries:         HSrank2classes-1.4.4-2FQFu50UwTCZnaeg8QB8J
depends:
    base-4.15.1.0 distributive-0.6.2.1-4SPuK3FbgMz4g7IeWkQbPP
    template-haskell-2.17.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
